@@ -24,6 +24,7 @@
 
 // Local includes
 #include "providers/providerinterface.hpp"
+#include "providers/accountsmodel.hpp"
 
 // Global includes
 #include <QtGui/QWidget>
@@ -43,14 +44,14 @@ public:
   MessageWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);
   ~MessageWidget();
 
-  /// Get/Set the provider info
-  void setProviderInfo(const ProviderInfo& providerInfo);
-  ProviderInfo providerInfo() const;
-
   /// Get/Set the provider
   void setProvider(const ProviderInterfacePtr& provider);
   ProviderInterfacePtr provider() const;
 
+  /// Get/Set the accounts
+  void setAccounts(const AccountsPtr& accounts);
+  AccountsPtr accounts() const;
+
 protected:
   MessageWidgetPrivate* d;
 };
